/*
  Copyright (c) 2015 NicoHood
  See the readme for credit to other people.

  MSGEQ7 Capture example
  Output via Serial

  Captures music via Serial into a PROGMEM array to use it later.
  Captured song example is "In The Morning Light (Radio Mix) - Robin Schulz"

  Reads MSGEQ7 IC with 7 different frequencys from range 0-255
  63Hz, 160Hz, 400Hz, 1kHz, 2.5kHz, 6.25KHz, 16kHz
*/

// MSGEQ7
#include "MSGEQ7.h"
#define pinAnalogLeft A0
#define pinAnalogRight A1
#define pinReset 6
#define pinStrobe 4
#define MSGEQ7_INTERVAL ReadsPerSecond(50)
#define MSGEQ7_SMOOTH false

CMSGEQ7<MSGEQ7_SMOOTH, pinReset, pinStrobe, pinAnalogLeft, pinAnalogRight> MSGEQ7;

void setup() {
  // Set the IC ready for reading
  MSGEQ7.begin();

  // Serial setup with faster baud rate gives more FPS (115200)
  Serial.begin(115200);

  while (true) {
    Serial.println(F("Waiting for a (single!) char to start."));
    Serial.println(F("Type 'P' for a playback of the capture."));
    Serial.println();

    // Wait for Serial to start capturing
    char c = 0;
    while ((c = Serial.read()) == -1);

    if (toupper(c) == 'P')
      printRecord();
    else
      break;
  }

  Serial.println(F("const uint8_t music[] PROGMEM = {"));
}

void loop() {
  static uint32_t count = 0;

  // Analyze without delay every interval
  bool newReading = MSGEQ7.read(MSGEQ7_INTERVAL);

  // Serial raw debug output
  if (newReading) {
    count++;

    // All channels together
    Serial.print(MSGEQ7.get(MSGEQ7_BASS));
    if (count % 10 != 0)
      Serial.print(F(", "));
    else
      Serial.println(F(","));
  }

  if (Serial.read() != -1) {
    Serial.println(0);
    Serial.println(F("};"));
    Serial.println();
    Serial.print(count);
    Serial.println(F(" bytes"));
    while (true);
  }
}

void printRecord() {
  // Print playback to the Serial
  for (uint32_t i = 0; i < getMusicSize(); i++)
  {
    // Visualize with characters as bars
    uint8_t input = getMusic(i);
    for (uint8_t i = 0; i < (input / 4); i++)
      Serial.print('=');
    Serial.println();

    // delaymicroseconds() is not precise on higher values
    delay(MSGEQ7_INTERVAL / 1000);
  }
  Serial.println(F("Playback finished"));
}


const uint8_t music[] PROGMEM = {
23, 20, 18, 16, 15, 15, 13, 14, 14, 15,
14, 14, 13, 14, 13, 14, 13, 15, 13, 14,
13, 15, 14, 14, 14, 14, 14, 14, 15, 14,
14, 14, 15, 13, 14, 14, 15, 13, 14, 13,
15, 13, 14, 15, 14, 15, 13, 15, 14, 14,
14, 14, 13, 15, 15, 14, 14, 14, 14, 14,
14, 14, 14, 14, 13, 14, 14, 14, 15, 14,
13, 15, 13, 14, 13, 14, 13, 15, 15, 14,
15, 14, 15, 15, 14, 14, 14, 15, 14, 14,
63, 155, 156, 130, 108, 90, 75, 62, 52, 44,
37, 33, 28, 24, 21, 19, 17, 16, 16, 16,
15, 16, 16, 15, 32, 128, 153, 144, 120, 100,
83, 69, 59, 50, 42, 36, 31, 27, 24, 21,
19, 16, 16, 16, 17, 15, 15, 16, 14, 93,
155, 144, 119, 98, 82, 68, 58, 49, 41, 36,
31, 27, 23, 21, 19, 16, 16, 17, 15, 17,
15, 15, 15, 33, 129, 155, 129, 107, 89, 74,
62, 53, 44, 38, 32, 28, 24, 22, 20, 17,
16, 17, 16, 15, 16, 15, 16, 15, 93, 153,
143, 119, 99, 82, 70, 58, 49, 42, 36, 31,
26, 24, 20, 19, 17, 16, 17, 15, 16, 16,
16, 16, 59, 126, 154, 126, 105, 88, 75, 63,
53, 45, 39, 33, 28, 25, 22, 19, 18, 16,
17, 16, 16, 16, 15, 15, 16, 92, 151, 140,
115, 98, 82, 68, 57, 48, 41, 36, 31, 26,
24, 20, 17, 17, 17, 16, 16, 15, 17, 16,
17, 57, 127, 152, 126, 106, 88, 74, 62, 53,
45, 39, 33, 29, 24, 22, 19, 18, 16, 17,
17, 16, 16, 15, 16, 16, 117, 154, 144, 119,
99, 83, 69, 58, 49, 42, 36, 31, 27, 23,
21, 19, 17, 17, 16, 18, 16, 16, 15, 17,
58, 155, 156, 128, 108, 90, 75, 63, 53, 45,
39, 33, 28, 25, 21, 19, 18, 17, 17, 16,
15, 16, 16, 16, 28, 128, 156, 143, 119, 98,
82, 68, 57, 49, 40, 35, 31, 26, 24, 21,
18, 17, 18, 16, 17, 17, 17, 16, 17, 94,
152, 141, 116, 99, 81, 68, 59, 49, 42, 37,
31, 27, 23, 20, 19, 17, 18, 18, 16, 17,
17, 16, 16, 32, 127, 154, 128, 106, 88, 74,
62, 53, 45, 38, 33, 28, 25, 22, 18, 19,
19, 18, 18, 18, 18, 17, 18, 16, 93, 154,
146, 120, 99, 83, 70, 59, 49, 43, 36, 31,
27, 24, 21, 18, 18, 18, 18, 17, 17, 17,
17, 17, 59, 128, 155, 129, 107, 89, 75, 63,
54, 45, 38, 32, 29, 24, 22, 21, 19, 18,
18, 19, 17, 17, 18, 17, 17, 93, 151, 144,
119, 105, 83, 70, 58, 49, 41, 37, 31, 27,
24, 21, 18, 20, 19, 18, 19, 19, 18, 17,
17, 58, 129, 156, 130, 107, 90, 75, 63, 54,
46, 37, 33, 28, 25, 21, 22, 20, 20, 18,
19, 19, 19, 17, 18, 17, 110, 151, 145, 121,
101, 82, 68, 58, 50, 43, 36, 31, 26, 24,
21, 20, 19, 19, 18, 18, 17, 18, 18, 18,
57, 152, 156, 128, 107, 90, 73, 62, 53, 44,
38, 32, 28, 25, 22, 22, 21, 21, 20, 19,
19, 19, 19, 19, 23, 130, 153, 147, 122, 101,
85, 70, 59, 50, 42, 37, 31, 27, 24, 21,
21, 21, 23, 20, 21, 21, 18, 18, 19, 95,
151, 141, 118, 99, 83, 68, 58, 49, 42, 36,
31, 27, 24, 23, 21, 22, 21, 22, 20, 19,
20, 20, 18, 33, 128, 155, 129, 105, 88, 75,
62, 52, 45, 38, 32, 28, 25, 22, 22, 22,
21, 19, 19, 19, 19, 18, 18, 18, 93, 155,
144, 119, 99, 82, 70, 58, 49, 42, 35, 31,
26, 25, 25, 23, 24, 23, 22, 21, 20, 21,
21, 19, 58, 131, 157, 130, 109, 90, 76, 64,
53, 46, 38, 33, 29, 26, 24, 23, 23, 23,
22, 22, 21, 19, 19, 20, 18, 92, 151, 142,
119, 98, 82, 69, 58, 49, 42, 36, 31, 27,
27, 24, 24, 25, 24, 21, 21, 21, 22, 21,
23, 57, 126, 149, 124, 103, 85, 70, 62, 51,
44, 37, 33, 28, 26, 26, 27, 23, 22, 21,
22, 21, 22, 19, 19, 21, 99, 154, 140, 117,
98, 82, 68, 57, 48, 41, 35, 30, 27, 28,
26, 28, 25, 27, 25, 25, 25, 25, 23, 25,
58, 147, 154, 127, 105, 89, 75, 63, 52, 45,
39, 33, 29, 27, 29, 27, 25, 25, 24, 23,
23, 21, 23, 23, 26, 125, 154, 147, 119, 98,
81, 69, 58, 49, 41, 35, 32, 28, 31, 29,
28, 29, 28, 28, 29, 26, 25, 26, 23, 92,
153, 146, 123, 101, 86, 70, 60, 50, 42, 36,
32, 27, 27, 29, 25, 27, 27, 28, 24, 24,
25, 23, 25, 24, 25, 27, 28, 27, 30, 27,
28, 27, 25, 26, 24, 28, 32, 32, 36, 31,
30, 29, 27, 24, 29, 29, 29, 28, 29, 28,
27, 29, 28, 31, 28, 27, 26, 24, 25, 22,
26, 31, 34, 31, 30, 29, 30, 28, 28, 27,
27, 27, 25, 43, 40, 40, 36, 43, 39, 35,
38, 38, 36, 32, 32, 34, 39, 37, 38, 41,
36, 39, 37, 42, 38, 38, 37, 36, 40, 35,
37, 33, 39, 34, 35, 32, 29, 30, 29, 33,
40, 37, 34, 30, 35, 31, 32, 31, 31, 29,
29, 26, 29, 31, 31, 32, 28, 34, 34, 33,
30, 32, 30, 30, 34, 33, 34, 33, 35, 32,
31, 27, 31, 28, 30, 29, 30, 33, 39, 34,
30, 30, 28, 31, 29, 25, 26, 23, 32, 32,
33, 33, 32, 34, 29, 30, 31, 29, 25, 27,
24, 44, 46, 52, 54, 50, 52, 54, 55, 47,
47, 48, 47, 46, 47, 47, 43, 47, 43, 44,
39, 39, 33, 38, 39, 40, 37, 41, 39, 37,
39, 35, 38, 34, 37, 34, 33, 38, 36, 34,
37, 33, 36, 32, 33, 31, 31, 31, 29, 33,
32, 34, 31, 34, 29, 32, 28, 29, 33, 29,
29, 32, 33, 39, 36, 35, 32, 32, 29, 29,
31, 28, 28, 27, 38, 37, 33, 39, 34, 29,
28, 29, 27, 27, 25, 23, 32, 33, 37, 33,
35, 30, 31, 27, 28, 28, 25, 28, 32, 37,
49, 52, 44, 46, 45, 45, 47, 49, 46, 48,
48, 52, 46, 49, 48, 49, 41, 43, 43, 44,
47, 45, 47, 49, 56, 52, 55, 51, 51, 48,
40, 44, 47, 48, 45, 50, 52, 52, 53, 51,
50, 48, 52, 46, 47, 47, 51, 46, 50, 49,
56, 51, 46, 50, 45, 50, 48, 48, 46, 48,
54, 51, 50, 48, 46, 44, 47, 43, 48, 47,
44, 43, 42, 51, 50, 52, 46, 43, 44, 41,
41, 42, 43, 42, 45, 49, 51, 46, 42, 43,
40, 44, 41, 41, 42, 42, 47, 53, 78, 66,
67, 59, 60, 53, 57, 58, 59, 54, 47, 53,
46, 52, 44, 56, 47, 47, 44, 43, 38, 44,
41, 50, 42, 41, 36, 44, 39, 36, 41, 38,
38, 36, 34, 36, 41, 38, 37, 36, 40, 35,
35, 34, 33, 33, 32, 31, 34, 29, 31, 38,
33, 30, 28, 31, 29, 30, 29, 35, 31, 39,
38, 33, 33, 33, 30, 32, 33, 31, 32, 31,
33, 31, 33, 29, 28, 30, 29, 29, 25, 25,
24, 26, 30, 38, 33, 34, 30, 32, 28, 30,
27, 27, 25, 26, 30, 45, 43, 38, 38, 37,
32, 35, 31, 42, 36, 39, 34, 38, 40, 39,
41, 37, 40, 36, 40, 37, 38, 37, 38, 42,
37, 38, 35, 38, 39, 33, 32, 29, 28, 29,
32, 36, 42, 36, 32, 33, 31, 32, 31, 31,
30, 29, 27, 30, 32, 36, 30, 35, 32, 32,
29, 32, 30, 28, 28, 36, 33, 35, 32, 30,
29, 28, 30, 30, 28, 28, 28, 28, 32, 35,
32, 31, 27, 27, 30, 28, 27, 27, 24, 31,
33, 35, 34, 34, 31, 36, 31, 31, 31, 27,
27, 25, 35, 54, 57, 62, 55, 56, 56, 53,
51, 46, 48, 47, 45, 49, 47, 41, 45, 40,
41, 35, 37, 30, 36, 36, 35, 38, 38, 39,
36, 39, 36, 36, 34, 35, 35, 33, 39, 41,
36, 37, 34, 35, 32, 34, 30, 34, 32, 30,
29, 34, 36, 35, 30, 30, 33, 32, 32, 30,
31, 30, 30, 33, 33, 33, 34, 33, 29, 28,
27, 27, 29, 28, 25, 32, 38, 35, 38, 34,
29, 27, 28, 27, 29, 27, 24, 30, 33, 38,
33, 35, 31, 30, 29, 29, 27, 25, 27, 25,
39, 42, 38, 40, 37, 35, 33, 33, 40, 34,
33, 32, 35, 43, 40, 46, 41, 42, 38, 40,
40, 42, 42, 42, 37, 39, 39, 42, 37, 36,
34, 34, 34, 34, 33, 31, 35, 36, 34, 33,
33, 32, 33, 29, 32, 29, 28, 30, 29, 30,
29, 29, 30, 30, 33, 30, 29, 27, 30, 27,
27, 33, 34, 32, 32, 32, 29, 27, 28, 30,
28, 25, 26, 28, 37, 32, 32, 32, 32, 30,
30, 26, 27, 25, 27, 31, 33, 40, 33, 31,
30, 31, 28, 28, 26, 27, 30, 29, 42, 46,
45, 49, 50, 52, 53, 48, 48, 44, 41, 48,
53, 50, 50, 51, 51, 51, 52, 45, 44, 44,
37, 37, 33, 44, 37, 40, 46, 40, 40, 41,
42, 41, 41, 40, 40, 35, 45, 38, 40, 38,
35, 36, 36, 39, 43, 37, 36, 38, 36, 40,
37, 38, 32, 37, 32, 32, 32, 31, 37, 34,
35, 42, 39, 39, 44, 80, 66, 68, 65, 58,
51, 75, 87, 87, 84, 110, 106, 101, 87, 90,
82, 77, 91, 109, 117, 115, 126, 133, 110, 93,
100, 93, 119, 114, 96, 160, 253, 253, 252, 224,
186, 155, 128, 107, 108, 169, 167, 190, 207, 218,
220, 219, 239, 235, 227, 238, 227, 222, 232, 223,
188, 253, 254, 253, 223, 186, 154, 127, 117, 125,
160, 192, 183, 202, 200, 187, 189, 197, 189, 197,
206, 193, 207, 189, 253, 253, 253, 253, 239, 199,
166, 137, 112, 119, 141, 172, 179, 199, 181, 200,
206, 203, 213, 225, 211, 224, 216, 199, 211, 253,
253, 254, 250, 212, 176, 145, 121, 101, 133, 145,
157, 177, 174, 176, 184, 177, 172, 188, 177, 167,
161, 153, 137, 201, 252, 252, 251, 230, 195, 158,
132, 120, 128, 135, 159, 169, 182, 170, 173, 160,
147, 152, 139, 142, 128, 136, 128, 164, 235, 254,
254, 219, 183, 151, 124, 103, 86, 95, 92, 99,
101, 118, 118, 112, 119, 114, 113, 108, 109, 104,
100, 95, 220, 253, 251, 250, 232, 194, 161, 134,
111, 94, 78, 69, 73, 71, 78, 71, 75, 73,
79, 77, 68, 80, 67, 75, 147, 250, 253, 253,
220, 182, 151, 125, 103, 88, 72, 71, 68, 84,
71, 87, 85, 87, 90, 75, 84, 73, 84, 77,
85, 234, 253, 253, 253, 220, 183, 151, 126, 133,
120, 99, 138, 115, 109, 103, 102, 97, 114, 106,
123, 120, 111, 138, 135, 250, 252, 252, 250, 220,
180, 148, 125, 105, 92, 123, 115, 142, 138, 115,
101, 111, 115, 106, 122, 114, 143, 145, 145, 121,
253, 253, 253, 252, 217, 178, 147, 123, 101, 94,
120, 132, 142, 118, 122, 127, 117, 126, 123, 133,
149, 146, 129, 152, 149, 253, 254, 254, 222, 184,
152, 126, 105, 109, 124, 144, 135, 148, 148, 141,
148, 140, 152, 161, 162, 145, 158, 153, 157, 195,
254, 253, 253, 220, 184, 153, 126, 117, 149, 152,
170, 182, 162, 169, 155, 158, 142, 151, 142, 147,
136, 140, 130, 173, 253, 253, 253, 218, 181, 150,
123, 103, 88, 86, 104, 99, 123, 117, 123, 114,
112, 115, 109, 102, 106, 105, 106, 167, 233, 253,
253, 235, 197, 162, 135, 112, 94, 79, 67, 75,
71, 77, 80, 75, 74, 79, 77, 77, 70, 76,
64, 78, 232, 253, 253, 253, 217, 179, 149, 123,
103, 85, 73, 77, 81, 77, 91, 84, 86, 79,
85, 74, 79, 74, 80, 81, 170, 224, 251, 252,
228, 190, 154, 130, 106, 101, 131, 174, 191, 206,
210, 221, 223, 240, 239, 229, 238, 230, 229, 228,
226, 188, 250, 250, 250, 230, 191, 158, 132, 112,
130, 152, 185, 199, 211, 210, 188, 200, 197, 181,
187, 181, 184, 188, 191, 252, 239, 253, 254, 234,
196, 162, 134, 112, 118, 142, 158, 194, 208, 202,
206, 207, 186, 209, 207, 200, 220, 219, 217, 225,
253, 253, 253, 252, 219, 182, 150, 125, 104, 135,
162, 179, 196, 187, 174, 174, 163, 156, 162, 167,
166, 169, 181, 175, 175, 254, 253, 253, 234, 195,
161, 134, 124, 135, 134, 163, 172, 184, 166, 173,
159, 162, 147, 153, 142, 128, 137, 130, 173, 244,
253, 253, 253, 215, 179, 148, 122, 100, 88, 91,
106, 118, 121, 115, 111, 108, 101, 107, 98, 109,
105, 106, 100, 214, 254, 254, 253, 237, 198, 163,
136, 112, 93, 78, 66, 72, 72, 78, 70, 71,
66, 73, 69, 76, 66, 77, 76, 112, 244, 252,
252, 242, 205, 170, 141, 118, 98, 81, 73, 71,
81, 72, 84, 74, 84, 79, 85, 78, 84, 88,
84, 94, 184, 253, 251, 251, 231, 193, 160, 132,
110, 126, 164, 173, 206, 212, 211, 225, 240, 232,
234, 238, 226, 235, 231, 222, 232, 193, 253, 253,
235, 195, 162, 134, 111, 111, 156, 162, 191, 211,
201, 209, 198, 190, 185, 184, 186, 191, 193, 200,
192, 252, 253, 250, 250, 234, 197, 160, 133, 111,
117, 150, 184, 181, 203, 197, 188, 199, 207, 196,
209, 225, 205, 224, 218, 223, 253, 253, 253, 215,
178, 149, 122, 107, 126, 139, 162, 185, 176, 169,
167, 167, 165, 173, 167, 183, 176, 174, 171, 157,
175, 147, 123, 143, 212, 185, 169, 142, 137, 119,
145, 123, 166, 172, 187, 200, 189, 215, 202, 228,
234, 210, 233, 204, 237, 222, 203, 215, 202, 211,
202, 207, 215, 187, 223, 193, 219, 203, 206, 212,
226, 231, 227, 209, 216, 205, 213, 213, 223, 227,
232, 243, 234, 241, 238, 206, 230, 210, 229, 234,
229, 237, 220, 239, 218, 240, 232, 195, 230, 214,
218, 210, 221, 238, 208, 173, 175, 208, 181, 164,
190, 195, 213, 229, 230, 234, 195, 167, 139, 194,
223, 189, 159, 168, 241, 204, 231, 192, 191, 253,
253, 250, 219, 180, 150, 124, 111, 126, 165, 188,
201, 208, 215, 211, 234, 231, 222, 232, 221, 216,
229, 227, 189, 250, 251, 251, 231, 195, 161, 133,
111, 128, 154, 156, 189, 201, 179, 200, 184, 192,
191, 187, 193, 199, 209, 186, 253, 246, 251, 253,
235, 199, 164, 136, 113, 96, 144, 141, 177, 195,
179, 195, 202, 198, 210, 216, 209, 223, 214, 217,
211, 253, 253, 253, 253, 227, 189, 156, 129, 107,
126, 152, 164, 173, 171, 170, 177, 177, 176, 184,
175, 175, 167, 153, 164, 191, 253, 252, 252, 229,
189, 155, 129, 120, 129, 135, 155, 167, 166, 158,
168, 157, 156, 147, 155, 138, 140, 133, 140, 161,
231, 254, 253, 253, 221, 184, 154, 127, 105, 97,
102, 112, 113, 124, 111, 115, 102, 112, 106, 104,
98, 110, 107, 106, 216, 253, 252, 252, 230, 194,
160, 131, 109, 90, 74, 67, 69, 78, 79, 82,
73, 66, 76, 64, 77, 70, 79, 68, 101, 248,
251, 250, 249, 211, 176, 146, 121, 101, 83, 72,
66, 87, 74, 78, 70, 79, 77, 84, 78, 87,
84, 92, 94, 185, 251, 253, 250, 219, 182, 150,
126, 132, 128, 118, 144, 118, 100, 121, 100, 111,
121, 106, 126, 126, 116, 128, 111, 112, 238, 251,
252, 250, 219, 182, 150, 125, 104, 86, 91, 114,
125, 104, 137, 150, 151, 128, 136, 113, 111, 122,
109, 120, 188, 253, 253, 253, 217, 180, 150, 124,
103, 92, 99, 116, 123, 140, 141, 146, 128, 126,
131, 118, 113, 121, 133, 138, 157, 243, 253, 253,
228, 190, 157, 129, 108, 100, 119, 125, 147, 153,
157, 143, 149, 147, 143, 147, 133, 142, 154, 151,
162, 205, 253, 253, 252, 228, 190, 155, 130, 123,
118, 143, 159, 177, 173, 170, 155, 163, 141, 146,
134, 135, 125, 142, 123, 162, 225, 251, 251, 217,
180, 149, 126, 105, 88, 96, 105, 112, 121, 102,
109, 103, 122, 115, 109, 97, 106, 108, 102, 102,
243, 252, 252, 253, 230, 192, 159, 131, 109, 91,
75, 73, 73, 74, 78, 69, 74, 78, 66, 77,
65, 79, 66, 81, 120, 251, 250, 250, 212, 175,
146, 119, 99, 83, 70, 75, 70, 79, 71, 78,
88, 89, 90, 77, 86, 77, 86, 73, 86, 234,
254, 253, 253, 230, 191, 158, 131, 109, 128, 164,
193, 196, 203, 223, 228, 239, 234, 236, 228, 228,
234, 228, 221, 218, 253, 253, 253, 232, 193, 161,
132, 111, 121, 155, 151, 182, 193, 193, 195, 204,
201, 209, 199, 167, 195, 187, 178, 173, 253, 254,
254, 253, 231, 192, 159, 132, 109, 136, 140, 172,
196, 205, 212, 203, 215, 213, 204, 206, 209, 188,
217, 215, 244, 253, 253, 253, 230, 192, 159, 132,
109, 111, 143, 165, 189, 181, 197, 192, 188, 181,
167, 150, 158, 151, 152, 160, 199, 253, 253, 252,
237, 198, 164, 136, 120, 132, 129, 158, 168, 173,
153, 166, 157, 157, 146, 154, 139, 143, 130, 141,
132, 209, 254, 252, 253, 220, 180, 150, 124, 102,
91, 92, 100, 96, 112, 97, 108, 111, 122, 121,
113, 105, 108, 107, 105, 202, 248, 253, 253, 234,
195, 161, 133, 111, 92, 77, 72, 71, 79, 70,
71, 77, 68, 75, 70, 78, 69, 75, 66, 83,
249, 254, 253, 253, 215, 179, 148, 123, 101, 84,
71, 67, 80, 72, 86, 80, 85, 85, 88, 74,
81, 74, 80, 71, 80, 100, 115, 101, 105, 87,
126, 175, 156, 192, 220, 236, 222, 222, 224, 218,
219, 244, 235, 233, 234, 231, 227, 233, 215, 207,
210, 219, 223, 233, 230, 210, 223, 220, 206, 213,
208, 201, 202, 209, 199, 211, 204, 181, 190, 182,
171, 178, 182, 179, 189, 198, 200, 200, 196, 200,
192, 179, 185, 186, 183, 203, 208, 200, 215, 209,
190, 206, 194, 182, 205, 205, 201, 209, 211, 212,
210, 203, 186, 189, 186, 178, 181, 176, 179, 174,
191, 181, 172, 171, 153, 139, 141, 143, 151, 154,
155, 138, 164, 165, 137, 143, 171, 153, 129, 113,
105, 114, 109, 103, 137, 122, 150, 135, 159, 170,
154, 173, 158, 170, 162, 137, 152, 128, 148, 140,
154, 152, 133, 142, 121, 130, 121, 106, 121, 109,
119, 113, 105, 111, 97, 110, 104, 90, 99, 83,
95, 84, 86, 90, 83, 91, 85, 100, 87, 75,
83, 70, 77, 86, 89, 84, 82, 88, 74, 82,
73, 64, 70, 60, 63, 59, 62, 61, 57, 70,
62, 57, 59, 49, 44, 42, 41, 45, 43, 50,
46, 41, 41, 42, 36, 32, 35, 30, 31, 27,
45, 53, 65, 56, 48, 41, 39, 39, 40, 36,
37, 32, 36, 47, 47, 40, 39, 43, 41, 39,
41, 36, 39, 38, 38, 38, 34, 41, 35, 37,
35, 34, 29, 31, 29, 31, 30, 39, 36, 33,
30, 35, 30, 31, 31, 30, 29, 29, 28, 29,
31, 34, 35, 32, 35, 31, 34, 30, 31, 28,
32, 35, 36, 34, 32, 31, 29, 28, 26, 29,
28, 26, 27, 29, 32, 37, 32, 31, 28, 28,
28, 28, 24, 25, 22, 31, 32, 34, 31, 29,
32, 29, 27, 28, 27, 25, 27, 28, 44, 51,
54, 56, 52, 52, 55, 51, 48, 53, 51, 48,
49, 50, 50, 45, 45, 43, 40, 40, 37, 37,
37, 37, 42, 38, 41, 40, 38, 40, 34, 39,
33, 34, 32, 32, 37, 37, 33, 36, 33, 36,
32, 33, 33, 30, 31, 28, 32, 32, 32, 31,
38, 33, 33, 32, 30, 31, 29, 30, 32, 34,
40, 35, 35, 31, 32, 29, 30, 31, 28, 28,
28, 38, 39, 33, 41, 34, 30, 28, 29, 27,
24, 25, 25, 34, 31, 38, 32, 35, 31, 29,
29, 30, 29, 26, 27, 33, 38, 54, 52, 44,
47, 45, 44, 49, 51, 44, 50, 50, 55, 47,
48, 46, 47, 41, 43, 45, 46, 47, 42, 49,
48, 57, 52, 55, 49, 50, 45, 39, 43, 44,
49, 45, 49, 53, 52, 52, 49, 49, 47, 51,
46, 47, 48, 51, 50, 50, 51, 52, 51, 46,
47, 44, 46, 48, 45, 44, 47, 53, 51, 50,
46, 44, 42, 44, 45, 40, 43, 42, 43, 43,
51, 51, 48, 45, 43, 42, 41, 39, 42, 42,
45, 46, 49, 45, 45, 41, 42, 40, 43, 41,
38, 38, 39, 49, 50, 80, 67, 67, 59, 59,
57, 54, 61, 56, 52, 48, 54, 45, 52, 45,
56, 49, 46, 43, 42, 43, 44, 42, 48, 41,
40, 36, 45, 39, 39, 39, 38, 38, 36, 34,
35, 42, 38, 37, 36, 39, 37, 32, 34, 33,
32, 32, 34, 32, 30, 31, 38, 33, 30, 28,
31, 31, 30, 33, 33, 32, 41, 38, 33, 34,
33, 30, 33, 30, 33, 29, 32, 32, 28, 33,
29, 29, 30, 28, 28, 25, 26, 23, 28, 30,
37, 32, 33, 28, 33, 28, 31, 28, 28, 26,
24, 36, 44, 43, 37, 38, 36, 32, 35, 35,
42, 40, 35, 33, 40, 40, 39, 41, 36, 39,
36, 36, 36, 36, 37, 36, 41, 36, 37, 35,
39, 33, 32, 32, 30, 29, 29, 32, 37, 39,
34, 32, 32, 31, 30, 31, 31, 29, 30, 27,
31, 30, 33, 31, 35, 31, 30, 30, 30, 27,
29, 29, 35, 32, 35, 33, 31, 31, 29, 31,
29, 27, 30, 27, 28, 32, 37, 33, 31, 27,
28, 29, 29, 27, 27, 24, 33, 32, 34, 34,
34, 34, 29, 30, 31, 31, 27, 27, 25, 44,
53, 58, 62, 56, 56, 54, 54, 50, 44, 51,
45, 44, 50, 46, 42, 47, 42, 43, 40, 37,
34, 33, 36, 40, 36, 41, 39, 36, 38, 36,
36, 34, 34, 35, 33, 39, 38, 35, 37, 33,
36, 33, 34, 29, 34, 31, 31, 32, 32, 34,
34, 31, 30, 34, 32, 32, 31, 31, 29, 32,
32, 33, 31, 34, 34, 31, 27, 26, 28, 29,
27, 24, 37, 36, 35, 40, 34, 30, 28, 26,
27, 29, 27, 26, 31, 34, 38, 33, 36, 31,
31, 26, 28, 28, 24, 27, 26, 39, 42, 38,
40, 36, 35, 33, 34, 39, 36, 33, 32, 35,
44, 38, 44, 41, 41, 38, 37, 39, 39, 39,
40, 38, 41, 38, 42, 38, 36, 34, 35, 34,
33, 33, 30, 35, 36, 33, 30, 33, 30, 31,
29, 31, 27, 27, 28, 27, 28, 25, 29, 28,
30, 31, 30, 28, 26, 28, 25, 27, 33, 32,
30, 32, 29, 28, 25, 25, 29, 28, 24, 25,
29, 34, 30, 30, 31, 30, 29, 29, 26, 25,
23, 25, 30, 30, 35, 31, 28, 27, 27, 26,
26, 24, 26, 27, 30, 37, 40, 46, 41, 42,
43, 47, 41, 43, 37, 36, 40, 39, 40, 40,
44, 43, 40, 40, 34, 36, 35, 31, 31, 26,
37, 31, 27, 31, 32, 30, 30, 30, 29, 29,
28, 45, 58, 99, 111, 101, 133, 130, 108, 118,
159, 130, 110, 93, 115, 96, 80, 66, 56, 48,
58, 54, 47, 48, 54, 45, 39, 34, 32, 40,
35, 34, 31, 29, 28, 26, 23, 22, 23, 24,
25, 26, 23, 25, 23, 25, 23, 21, 19, 24,
26, 26, 23, 22, 21, 22, 23, 22, 22, 20,
21, 24, 174, 253, 252, 251, 229, 192, 158, 132,
110, 103, 158, 172, 193, 198, 181, 211, 231, 220,
235, 238, 239, 233, 239, 234, 210, 174, 254, 253,
253, 226, 187, 155, 128, 107, 109, 149, 171, 174,
189, 196, 202, 205, 208, 185, 194, 189, 165, 181,
174, 253, 253, 253, 253, 241, 202, 167, 138, 115,
102, 123, 163, 170, 197, 208, 213, 210, 196, 214,
211, 188, 207, 211, 188, 249, 251, 251, 252, 233,
193, 159, 133, 112, 108, 131, 144, 163, 182, 191,
175, 196, 185, 167, 166, 145, 140, 153, 157, 157,
254, 254, 254, 253, 240, 202, 167, 139, 114, 120,
127, 148, 151, 168, 147, 159, 135, 145, 127, 143,
119, 134, 118, 125, 167, 225, 253, 253, 225, 187,
155, 129, 107, 89, 79, 86, 88, 107, 105, 109,
104, 110, 111, 113, 107, 109, 101, 97, 89, 244,
251, 250, 251, 238, 198, 164, 136, 113, 94, 79,
73, 67, 75, 70, 63, 74, 71, 63, 67, 61,
74, 65, 77, 144, 253, 254, 253, 227, 189, 155,
129, 107, 90, 74, 65, 65, 80, 77, 82, 83,
70, 81, 70, 84, 71, 79, 70, 90, 233, 251,
254, 250, 229, 192, 159, 133, 111, 108, 91, 137,
113, 121, 114, 94, 116, 129, 112, 121, 104, 108,
123, 115, 252, 254, 253, 253, 232, 193, 159, 132,
110, 91, 110, 90, 132, 149, 132, 126, 124, 121,
114, 130, 124, 141, 153, 155, 129, 252, 252, 251,
251, 218, 179, 151, 126, 109, 97, 134, 150, 161,
146, 150, 134, 126, 137, 121, 139, 163, 153, 160,
132, 171, 254, 253, 253, 235, 196, 162, 134, 112,
100, 118, 148, 135, 152, 141, 120, 130, 128, 137,
147, 153, 161, 134, 153, 164, 227, 253, 254, 251,
244, 204, 170, 141, 117, 128, 147, 162, 172, 173,
168, 157, 154, 146, 154, 140, 145, 132, 131, 120,
198, 253, 253, 253, 223, 185, 153, 126, 104, 86,
87, 98, 105, 111, 102, 107, 99, 105, 106, 115,
111, 113, 106, 109, 225, 242, 253, 253, 239, 199,
165, 137, 114, 94, 79, 67, 76, 76, 79, 74,
80, 67, 78, 65, 73, 63, 73, 74, 120, 243,
253, 253, 253, 221, 184, 153, 126, 105, 87, 73,
65, 81, 69, 82, 68, 85, 73, 84, 73, 82,
69, 84, 72, 188, 244, 253, 253, 233, 194, 161,
132, 111, 106, 142, 182, 201, 191, 216, 220, 229,
242, 236, 243, 239, 232, 237, 230, 217, 181, 253,
253, 253, 228, 190, 158, 131, 112, 112, 146, 162,
171, 190, 197, 193, 202, 199, 182, 195, 194, 172,
174, 167, 251, 251, 250, 251, 226, 188, 154, 128,
109, 102, 130, 134, 176, 188, 204, 207, 210, 208,
209, 206, 194, 202, 204, 193, 211, 252, 253, 254,
254, 236, 197, 164, 135, 112, 138, 150, 164, 179,
185, 169, 185, 183, 166, 162, 149, 142, 155, 158,
159, 151, 253, 253, 253, 225, 187, 156, 128, 107,
126, 131, 158, 164, 178, 181, 157, 167, 164, 151,
143, 129, 133, 124, 116, 161, 213, 253, 253, 246,
207, 171, 140, 117, 98, 84, 83, 80, 101, 119,
100, 117, 117, 108, 114, 99, 104, 106, 104, 99,
212, 254, 251, 253, 238, 199, 165, 137, 114, 94,
79, 66, 75, 77, 75, 68, 71, 76, 76, 70,
76, 78, 76, 80, 145, 237, 254, 250, 214, 179,
149, 122, 102, 84, 71, 62, 61, 76, 75, 84,
78, 85, 75, 79, 83, 69, 79, 69, 79, 96,
83, 119, 103, 98, 133, 144, 174, 158, 223, 235,
223, 222, 227, 227, 239, 244, 233, 246, 241, 232,
240, 237, 230, 232, 238, 234, 234, 234, 214, 225,
223, 204, 216, 211, 208, 212, 213, 203, 209, 214,
200, 207, 200, 190, 185, 177, 179, 179, 181, 190,
194, 178, 190, 184, 170, 182, 183, 179, 188, 200,
187, 214, 210, 203, 217, 206, 192, 209, 207, 201,
216, 217, 218, 207, 209, 208, 201, 195, 185, 196,
190, 184, 184, 187, 190, 191, 194, 177, 165, 163,
155, 153, 156, 169, 162, 173, 185, 190, 163, 143,
146, 210, 193, 171, 141, 128, 119, 146, 126, 152,
167, 149, 192, 178, 213, 198, 218, 222, 204, 223,
194, 219, 202, 173, 224, 204, 222, 220, 223, 208,
204, 206, 202, 198, 205, 193, 203, 199, 225, 215,
227, 236, 223, 231, 222, 211, 197, 170, 166, 172,
185, 201, 182, 197, 166, 191, 183, 178, 189, 173,
202, 228, 218, 237, 202, 222, 186, 209, 209, 195,
217, 207, 226, 240, 228, 246, 225, 240, 209, 229,
226, 203, 225, 224, 237, 243, 230, 246, 220, 239,
211, 225, 226, 204, 228, 190, 254, 253, 219, 182,
150, 122, 102, 111, 137, 183, 199, 190, 194, 203,
193, 230, 226, 226, 233, 235, 235, 229, 231, 193,
253, 253, 253, 229, 191, 157, 130, 113, 128, 150,
192, 193, 204, 209, 196, 203, 188, 191, 177, 177,
181, 186, 195, 253, 248, 252, 253, 237, 198, 163,
135, 113, 116, 133, 152, 182, 202, 194, 201, 198,
187, 200, 209, 198, 218, 220, 209, 221, 253, 253,
254, 253, 219, 180, 148, 121, 102, 129, 158, 173,
189, 191, 168, 174, 162, 165, 158, 167, 154, 170,
169, 172, 192, 254, 254, 252, 217, 180, 149, 124,
123, 133, 139, 155, 172, 166, 171, 157, 153, 137,
151, 143, 143, 138, 138, 139, 162, 235, 253, 251,
252, 214, 177, 147, 122, 101, 88, 99, 108, 104,
129, 115, 118, 108, 109, 100, 105, 109, 103, 100,
98, 226, 252, 253, 253, 236, 198, 163, 134, 112,
93, 78, 65, 65, 71, 66, 76, 73, 73, 65,
65, 71, 61, 80, 76, 104, 231, 251, 250, 250,
210, 175, 147, 122, 101, 85, 72, 71, 88, 77,
89, 74, 85, 73, 86, 73, 83, 83, 84, 100,
174, 253, 253, 251, 218, 181, 150, 124, 132, 109,
118, 148, 120, 118, 131, 110, 115, 128, 107, 133,
111, 115, 135, 114, 233, 238, 253, 252, 220, 184,
152, 126, 104, 102, 87, 102, 104, 95, 97, 102,
119, 139, 141, 120, 119, 141, 140, 116, 104, 246,
253, 253, 252, 214, 178, 146, 122, 102, 87, 98,
108, 134, 121, 126, 124, 137, 124, 155, 141, 140,
131, 123, 134, 155, 212, 252, 250, 213, 177, 148,
123, 102, 99, 111, 126, 134, 149, 148, 148, 144,
155, 153, 147, 141, 140, 141, 143, 129, 197, 253,
253, 253, 229, 191, 158, 131, 124, 128, 156, 171,
189, 166, 163, 171, 161, 152, 159, 141, 142, 140,
148, 137, 182, 252, 250, 252, 213, 178, 148, 123,
102, 85, 94, 103, 113, 123, 115, 111, 99, 108,
101, 106, 96, 112, 104, 104, 99, 243, 252, 251,
250, 236, 199, 166, 138, 113, 94, 78, 72, 71,
78, 74, 79, 66, 75, 63, 71, 67, 81, 67,
83, 132, 254, 253, 253, 214, 178, 147, 121, 99,
83, 71, 71, 77, 69, 78, 66, 81, 70, 81,
78, 81, 81, 81, 75, 89, 213, 253, 253, 252,
222, 183, 151, 123, 110, 129, 163, 198, 190, 192,
216, 204, 237, 235, 229, 232, 234, 233, 228, 232,
199, 251, 251, 250, 239, 197, 165, 138, 114, 133,
160, 156, 195, 198, 184, 191, 184, 184, 202, 198,
193, 209, 207, 187, 250, 251, 251, 253, 246, 211,
176, 147, 121, 101, 136, 140, 170, 191, 180, 194,
205, 200, 217, 219, 221, 222, 208, 220, 215, 230,
253, 253, 252, 229, 190, 156, 129, 107, 120, 144,
159, 164, 167, 175, 185, 170, 185, 177, 170, 170,
161, 152, 149, 207, 251, 252, 251, 223, 186, 156,
128, 130, 146, 155, 171, 182, 184, 178, 160, 169,
154, 157, 151, 136, 122, 137, 137, 169, 218, 253,
254, 253, 213, 178, 147, 121, 101, 86, 91, 98,
102, 121, 107, 98, 103, 110, 106, 112, 98, 104,
103, 98, 222, 247, 255, 252, 237, 201, 166, 136,
113, 94, 79, 68, 70, 80, 77, 77, 75, 64,
78, 68, 77, 66, 68, 62, 117, 239, 254, 253,
252, 215, 177, 147, 120, 100, 85, 70, 64, 84,
71, 86, 73, 79, 73, 86, 78, 86, 79, 85,
76, 158, 251, 253, 250, 221, 185, 153, 127, 106,
112, 178, 185, 192, 201, 203, 211, 228, 239, 238,
237, 238, 232, 226, 235, 213, 175, 249, 252, 251,
225, 187, 156, 129, 137, 137, 174, 197, 172, 202,
195, 180, 190, 189, 197, 200, 206, 184, 201, 190,
253, 252, 252, 252, 231, 193, 159, 132, 118, 127,
155, 186, 188, 204, 197, 205, 207, 204, 210, 211,
201, 217, 219, 202, 233, 251, 243, 251, 247, 207,
172, 143, 132, 138, 157, 163, 173, 180, 181, 169,
177, 168, 157, 165, 156, 144, 161, 148, 141, 160,
252, 249, 245, 205, 173, 141, 118, 105, 103, 123,
109, 116, 122, 155, 166, 171, 190, 162, 179, 170,
187, 173, 156, 200, 168, 231, 229, 190, 157, 130,
111, 95, 112, 125, 114, 128, 116, 134, 116, 105,
111, 94, 111, 105, 92, 106, 92, 98, 122, 118,
101, 86, 73, 70, 69, 80, 73, 72, 67, 75,
69, 68, 66, 59, 61, 55, 57, 54, 54, 57,
49, 52, 54, 57, 53, 53, 51, 50, 43, 42,
38, 39, 38, 41, 39, 38, 39, 37, 39, 35,
33, 32, 30, 28, 26, 32, 32, 40, 45, 39,
37, 34, 30, 41, 36, 31, 36, 35, 32, 37,
39, 38, 36, 36, 37, 33, 34, 34, 36, 34,
36, 35, 37, 32, 34, 33, 33, 31, 33, 30,
31, 29, 34, 31, 29, 25, 26, 28, 29, 26,
25, 26, 27, 24, 26, 24, 25, 26, 26, 25,
25, 27, 27, 28, 26, 25, 26, 24, 23, 25,
27, 25, 25, 24, 25, 26, 24, 28, 26, 24,
24, 21, 22, 22, 21, 22, 22, 24, 20, 22,
21, 21, 19, 21, 20, 23, 23, 23, 21, 22,
24, 23, 22, 19, 27, 50, 47, 54, 50, 52,
54, 55, 49, 46, 43, 41, 45, 41, 43, 44,
45, 41, 41, 37, 35, 35, 33, 37, 34, 37,
39, 42, 39, 37, 35, 35, 33, 36, 34, 34,
33, 31, 30, 28, 26, 28, 27, 25, 25, 25,
25, 24, 24, 23, 26, 26, 28, 26, 25, 26,
25, 25, 21, 22, 22, 23, 24, 28, 28, 27,
25, 25, 21, 22, 20, 21, 20, 19, 35, 36,
31, 38, 32, 29, 28, 29, 26, 25, 26, 23,
27, 26, 27, 26, 29, 26, 26, 25, 24, 22,
24, 22, 30, 38, 55, 49, 44, 51, 45, 47,
40, 40, 40, 46, 48, 45, 43, 48, 44, 46,
41, 40, 45, 43, 43, 40, 45, 52, 56, 49,
47, 50, 50, 50, 43, 47, 47, 48, 42, 42,
47, 45, 45, 43, 44, 44, 47, 43, 45, 46,
43, 44, 43, 49, 47, 48, 48, 49, 47, 46,
47, 44, 42, 42, 42, 43, 46, 48, 43, 45,
45, 44, 40, 44, 41, 40, 41, 43, 45, 42,
44, 46, 46, 43, 43, 40, 37, 41, 39, 42,
40, 40, 35, 37, 37, 36, 41, 37, 41, 42,
44, 51, 84, 70, 62, 62, 62, 60, 58, 56,
56, 52, 45, 48, 41, 53, 50, 46, 45, 44,
37, 44, 39, 40, 35, 42, 37, 33, 30, 39,
34, 31, 36, 32, 36, 33, 32, 31, 32, 28,
30, 24, 30, 27, 24, 26, 24, 28, 26, 26,
24, 26, 27, 28, 25, 25, 23, 25, 22, 22,
23, 23, 27, 30, 30, 27, 26, 25, 24, 23,
26, 24, 25, 24, 25, 25, 24, 24, 24, 25,
26, 25, 23, 22, 22, 24, 24, 23, 22, 22,
20, 21, 23, 23, 22, 21, 20, 20, 33, 40,
42, 37, 33, 30, 30, 35, 33, 34, 32, 35,
35, 36, 33, 34, 34, 36, 33, 38, 33, 32,
31, 32, 31, 33, 31, 35, 33, 32, 31, 29,
28, 27, 28, 29, 29, 27, 26, 27, 26, 25,
24, 25, 26, 25, 23, 23, 23, 24, 27, 26,
23, 25, 26, 26, 25, 25, 24, 26, 25, 22,
24, 24, 24, 25, 23, 24, 24, 24, 26, 24,
25, 23, 22, 23, 21, 22, 23, 21, 23, 21,
22, 20, 19, 21, 20, 20, 23, 22, 24, 23,
23, 24, 22, 21, 20, 27, 51, 47, 56, 48,
52, 52, 54, 47, 45, 46, 42, 44, 42, 43,
41, 46, 40, 40, 36, 38, 37, 33, 39, 34,
36, 40, 40, 37, 37, 35, 34, 34, 36, 35,
34, 33, 32, 31, 28, 25, 27, 28, 25, 27,
25, 25, 23, 24, 24, 24, 25, 27, 27, 26,
26, 25, 25, 23, 21, 22, 23, 23, 28, 28,
28, 25, 25, 22, 21, 22, 21, 21, 19, 20,
20, 24, 28, 26, 25, 25, 23, 22, 24, 23,
22, 21, 24, 22, 23, 23, 24, 23, 22, 21,
21, 20, 17, 29, 40, 43, 39, 39, 42, 38,
38, 34, 36, 36, 34, 35, 34, 42, 39, 42,
41, 41, 37, 37, 39, 41, 40, 40, 41, 39,
35, 40, 35, 38, 33, 33, 31, 33, 35, 32,
30, 28, 27, 26, 27, 26, 26, 27, 25, 27,
28, 26, 25, 26, 27, 26, 28, 27, 28, 30,
27, 25, 27, 25, 26, 24, 25, 25, 26, 23,
25, 23, 28, 27, 24, 21, 23, 24, 25, 26,
27, 26, 25, 25, 24, 23, 22, 21, 20, 24,
25, 24, 23, 21, 20, 20, 22, 21, 23, 23,
25, 33, 50, 50, 54, 46, 48, 51, 50, 47,
46, 45, 50, 48, 50, 48, 44, 52, 54, 46,
50, 52, 47, 44, 45, 44, 38, 49, 41, 38,
46, 47, 45, 42, 42, 37, 42, 37, 45, 66,
109, 115, 101, 127, 139, 116, 129, 160, 132, 108,
91, 104, 102, 86, 72, 61, 51, 70, 63, 59,
59, 52, 47, 43, 40, 47, 49, 42, 42, 39,
33, 38, 34, 31, 32, 29, 32, 32, 29, 32,
35, 33, 32, 32, 30, 29, 34, 34, 34, 33,
30, 28, 31, 29, 31, 31, 27, 27, 36, 115,
139, 117, 98, 81, 68, 57, 49, 42, 38, 33,
37, 37, 39, 35, 37, 42, 38, 37, 37, 45,
38, 42, 39, 94, 138, 121, 101, 84, 70, 59,
50, 43, 36, 32, 32, 32, 38, 38, 33, 32,
33, 31, 32, 32, 31, 30, 27, 57, 120, 139,
116, 96, 80, 67, 57, 48, 42, 36, 31, 30,
34, 31, 33, 32, 34, 31, 27, 28, 30, 29,
31, 28, 90, 122, 125, 103, 86, 72, 60, 51,
43, 37, 32, 28, 28, 37, 34, 34, 34, 31,
36, 30, 31, 29, 27, 27, 53, 117, 136, 113,
95, 78, 65, 55, 55, 51, 47, 47, 46, 44,
45, 44, 43, 47, 40, 40, 37, 41, 36, 37,
39, 101, 126, 112, 94, 78, 66, 56, 47, 39,
36, 36, 32, 36, 38, 33, 35, 34, 35, 32,
31, 29, 33, 32, 31, 50, 123, 137, 114, 95,
78, 66, 56, 47, 41, 35, 30, 31, 31, 33,
36, 36, 31, 33, 28, 31, 29, 29, 31, 28,
114, 121, 121, 100, 84, 70, 59, 50, 42, 36,
32, 28, 32, 33, 35, 31, 33, 31, 28, 28,
29, 29, 27, 26, 87, 134, 140, 115, 97, 84,
67, 56, 48, 48, 44, 47, 45, 50, 47, 44,
47, 46, 44, 43, 41, 44, 45, 45, 46, 129,
131, 108, 89, 75, 64, 54, 45, 38, 43, 45,
42, 49, 51, 51, 47, 50, 45, 50, 51, 51,
46, 48, 50, 77, 151, 147, 122, 101, 84, 71,
59, 51, 46, 47, 44, 47, 51, 50, 50, 46,
45, 43, 44, 41, 44, 42, 41, 68, 125, 137,
113, 94, 79, 67, 56, 47, 41, 41, 42, 41,
45, 46, 50, 43, 44, 41, 41, 43, 41, 40,
38, 44, 73, 138, 136, 113, 94, 79, 66, 55,
55, 52, 60, 54, 46, 51, 44, 51, 44, 56,
47, 46, 43, 43, 36, 43, 61, 125, 113, 94,
79, 66, 55, 46, 41, 36, 37, 33, 34, 36,
40, 38, 36, 35, 38, 35, 33, 33, 29, 32,
31, 97, 140, 136, 112, 93, 78, 65, 55, 47,
40, 34, 30, 34, 33, 37, 36, 33, 34, 32,
29, 33, 32, 30, 32, 55, 103, 127, 105, 88,
73, 62, 52, 44, 37, 33, 29, 28, 29, 34,
34, 32, 29, 31, 29, 30, 27, 28, 25, 26,
121, 134, 127, 105, 87, 73, 61, 52, 44, 40,
39, 37, 33, 38, 39, 39, 40, 37, 36, 38,
36, 42, 38, 35, 96, 133, 132, 110, 92, 77,
65, 54, 46, 39, 34, 29, 30, 34, 38, 34,
33, 33, 30, 32, 31, 30, 30, 28, 30, 126,
128, 119, 99, 83, 69, 59, 50, 43, 36, 31,
28, 34, 31, 36, 32, 30, 29, 27, 31, 29,
29, 27, 27, 91, 121, 135, 112, 93, 77, 65,
54, 47, 39, 34, 29, 28, 32, 35, 33, 35,
31, 35, 29, 30, 29, 26, 26, 36, 120, 138,
114, 96, 80, 67, 57, 54, 50, 43, 48, 45,
45, 50, 46, 41, 44, 39, 41, 36, 37, 31,
34, 34, 95, 129, 118, 98, 81, 69, 57, 49,
41, 35, 33, 32, 32, 40, 36, 36, 37, 35,
31, 34, 30, 33, 30, 32, 52, 121, 135, 111,
93, 78, 66, 55, 46, 40, 35, 30, 30, 32,
30, 35, 34, 34, 31, 28, 26, 29, 28, 28,
26, 95, 119, 134, 111, 92, 78, 65, 55, 46,
39, 34, 30, 29, 34, 36, 31, 34, 30, 30,
29, 26, 28, 24, 26, 25, 38, 42, 40, 40,
37, 35, 33, 32, 39, 36, 33, 32, 36, 41,
40, 42, 41, 40, 37, 40, 40, 36, 44, 43,
37, 35, 34, 41, 35, 37, 36, 35, 34, 36,
33, 34, 35, 36, 35, 34, 34, 30, 29, 31,
35, 30, 28, 30, 33, 32, 29, 30, 29, 28,
33, 29, 29, 26, 29, 27, 29, 36, 33, 33,
35, 33, 29, 28, 27, 29, 30, 27, 25, 29,
28, 32, 32, 30, 33, 30, 30, 31, 27, 25,
26, 30, 31, 36, 35, 30, 30, 30, 29, 27,
28, 27, 29, 31, 42, 44, 45, 52, 55, 49,
94, 92, 77, 65, 56, 62, 101, 89, 75, 64,
55, 52, 48, 47, 47, 43, 41, 41, 136, 162,
153, 161, 171, 144, 148, 122, 102, 85, 71, 60,
50, 43, 45, 45, 55, 47, 46, 39, 68, 61,
54, 45, 43, 213, 225, 188, 164, 161, 133, 110,
94, 77, 66, 55, 55, 61, 55, 46, 50, 47,
45, 65, 116, 96, 80, 67, 56, 153, 220, 235,
196, 185, 158, 146, 126, 104, 87, 73, 62, 64,
76, 67, 58, 48, 45, 51, 100, 90, 76, 64,
53, 149, 232, 253, 253, 218, 180, 148, 126, 103,
104, 128, 176, 187, 197, 206, 218, 222, 234, 235,
230, 228, 226, 230, 223, 217, 201, 251, 254, 253,
219, 182, 150, 125, 124, 131, 168, 198, 182, 187,
174, 167, 175, 192, 189, 201, 204, 197, 202, 180,
253, 252, 253, 253, 235, 196, 162, 133, 110, 116,
138, 143, 180, 194, 183, 206, 209, 204, 212, 216,
202, 226, 219, 195, 211, 253, 253, 253, 253, 219,
182, 151, 124, 104, 130, 145, 158, 179, 176, 172,
184, 178, 168, 185, 176, 163, 158, 150, 140, 213,
253, 254, 253, 230, 192, 159, 131, 119, 128, 141,
160, 174, 182, 167, 159, 147, 159, 154, 140, 135,
131, 137, 134, 154, 219, 253, 253, 253, 214, 177,
146, 119, 101, 91, 98, 108, 105, 121, 108, 112,
118, 122, 110, 98, 101, 104, 100, 102, 206, 253,
253, 253, 229, 190, 157, 130, 108, 90, 76, 73,
74, 78, 79, 77, 78, 70, 81, 68, 82, 82,
74, 79, 112, 223, 250, 251, 212, 176, 147, 123,
101, 85, 72, 74, 71, 80, 70, 82, 78, 84,
86, 89, 88, 82, 88, 77, 93, 179, 253, 252,
252, 215, 176, 146, 120, 133, 112, 116, 149, 122,
121, 109, 104, 120, 127, 108, 131, 109, 115, 137,
117, 247, 208, 253, 252, 222, 185, 153, 127, 106,
88, 87, 107, 132, 135, 141, 147, 152, 134, 123,
102, 106, 110, 129, 132, 109, 252, 251, 251, 252,
214, 179, 148, 123, 102, 90, 111, 131, 138, 125,
138, 141, 124, 102, 124, 116, 120, 125, 126, 148,
130, 246, 252, 251, 211, 175, 143, 120, 99, 110,
116, 141, 141, 150, 148, 140, 137, 143, 144, 148,
137, 142, 150, 152, 137, 238, 253, 253, 253, 229,
191, 158, 131, 127, 152, 151, 175, 171, 154, 155,
155, 160, 146, 155, 138, 142, 138, 141, 130, 168,
254, 253, 252, 213, 177, 146, 121, 101, 98, 97,
112, 114, 121, 107, 114, 102, 114, 108, 104, 90,
106, 108, 108, 105, 227, 251, 251, 250, 215, 177,
148, 122, 101, 85, 70, 68, 77, 80, 85, 76,
71, 76, 65, 78, 68, 83, 70, 85, 121, 254,
253, 252, 214, 178, 147, 122, 101, 84, 71, 71,
82, 71, 91, 75, 83, 78, 80, 71, 81, 84,
87, 78, 142, 221, 253, 253, 231, 192, 160, 132,
110, 108, 132, 166, 194, 204, 210, 223, 224, 240,
238, 229, 231, 231, 225, 227, 221, 185, 249, 252,
252, 223, 186, 154, 127, 114, 135, 163, 184, 195,
204, 181, 196, 187, 194, 196, 196, 190, 201, 207,
188, 253, 237, 253, 253, 227, 188, 155, 129, 107,
99, 148, 146, 182, 204, 190, 201, 208, 194, 211,
219, 202, 222, 220, 207, 218, 253, 253, 253, 253,
221, 184, 152, 126, 104, 122, 154, 167, 178, 171,
168, 174, 176, 173, 180, 169, 175, 161, 150, 158,
201, 253, 254, 253, 239, 201, 166, 137, 120, 140,
134, 160, 177, 182, 162, 164, 155, 158, 145, 150,
136, 141, 139, 134, 161, 224, 253, 253, 253, 211,
174, 145, 122, 101, 103, 102, 108, 105, 123, 113,
117, 103, 112, 104, 106, 105, 106, 107, 103, 203,
253, 251, 251, 222, 186, 153, 126, 105, 88, 74,
65, 77, 84, 78, 82, 75, 73, 74, 66, 77,
68, 78, 68, 102, 221, 253, 252, 252, 214, 178,
148, 123, 102, 85, 76, 67, 79, 68, 80, 72,
79, 81, 87, 79, 85, 79, 85, 89, 73, 100,
121, 104, 107, 88, 129, 183, 153, 195, 237, 224,
223, 225, 205, 222, 241, 236, 235, 234, 222, 233,
236, 226, 219, 208, 201, 202, 208, 221, 225, 220,
232, 224, 212, 227, 221, 201, 207, 197, 196, 201,
205, 194, 208, 206, 181, 200, 191, 173, 179, 167,
176, 171, 203, 184, 204, 211, 187, 204, 200, 183,
198, 213, 199, 211, 216, 218, 215, 211, 219, 213,
210, 214, 194, 200, 206, 209, 212, 217, 200, 198,
199, 184, 173, 188, 175, 174, 167, 183, 180, 174,
182, 168, 154, 148, 149, 144, 164, 146, 121, 137,
196, 179, 162, 135, 134, 127, 150, 127, 154, 129,
173, 190, 177, 214, 198, 228, 222, 224, 233, 203,
220, 201, 173, 170, 161, 188, 184, 223, 230, 203,
221, 207, 212, 211, 198, 201, 189, 206, 197, 205,
201, 203, 213, 219, 233, 225, 189, 213, 189, 217,
220, 224, 225, 222, 233, 215, 236, 228, 189, 204,
187, 209, 222, 214, 232, 230, 240, 218, 238, 233,
193, 206, 194, 216, 219, 205, 223, 216, 233, 238,
239, 227, 199, 216, 190, 213, 234, 218, 232, 218,
236, 233, 196, 206, 175, 253, 254, 253, 225, 186,
152, 129, 115, 130, 169, 187, 202, 195, 207, 215,
238, 234, 233, 227, 217, 225, 228, 224, 197, 252,
253, 250, 218, 189, 152, 127, 103, 125, 153, 153,
175, 183, 174, 183, 189, 188, 200, 196, 172, 188,
194, 172, 174, 253, 254, 254, 250, 211, 175, 146,
120, 100, 142, 146, 176, 194, 205, 204, 203, 201,
208, 195, 209, 213, 186, 206, 210, 248, 250, 252,
252, 217, 180, 150, 125, 105, 122, 143, 172, 193,
178, 187, 182, 173, 182, 163, 151, 150, 146, 153,
168, 160, 253, 253, 253, 226, 188, 156, 129, 118,
129, 144, 161, 168, 162, 149, 156, 148, 153, 145,
149, 129, 131, 131, 144, 138, 208, 252, 252, 252,
215, 179, 147, 123, 102, 95, 93, 99, 95, 110,
94, 110, 108, 124, 122, 114, 105, 102, 108, 105,
200, 218, 254, 253, 230, 191, 158, 131, 109, 91,
76, 68, 70, 70, 79, 72, 79, 75, 79, 72,
80, 70, 77, 65, 84, 234, 253, 253, 252, 213,
177, 146, 122, 101, 85, 72, 63, 84, 70, 83,
81, 87, 86, 89, 75, 87, 77, 84, 76, 160,
253, 253, 252, 218, 181, 149, 124, 103, 141, 122,
150, 125, 103, 112, 106, 111, 124, 109, 104, 122,
115, 133, 131, 120, 241, 250, 251, 250, 215, 175,
146, 122, 102, 92, 117, 145, 120, 131, 120, 106,
114, 108, 106, 105, 120, 146, 122, 145, 213, 253,
253, 253, 215, 179, 147, 122, 101, 95, 123, 135,
136, 146, 130, 119, 110, 116, 123, 122, 124, 118,
142, 142, 132, 230, 251, 252, 250, 212, 176, 147,
123, 103, 124, 123, 148, 131, 135, 130, 132, 145,
143, 162, 138, 147, 158, 154, 135, 164, 254, 253,
253, 227, 188, 156, 129, 127, 120, 150, 154, 165,
173, 165, 161, 162, 139, 149, 127, 130, 121, 136,
116, 160, 216, 250, 253, 211, 175, 145, 120, 100,
83, 89, 88, 112, 105, 117, 115, 106, 108, 111,
100, 90, 96, 98, 101, 100, 202, 253, 253, 253,
221, 183, 152, 126, 104, 87, 73, 64, 78, 71,
75, 68, 73, 67, 73, 80, 65, 81, 70, 84,
116, 229, 253, 254, 215, 178, 147, 123, 102, 84,
70, 76, 77, 85, 78, 88, 86, 82, 85, 72,
80, 75, 79, 79, 97, 217, 253, 253, 253, 226,
189, 156, 129, 107, 129, 163, 175, 205, 207, 210,
225, 235, 233, 238, 231, 227, 230, 223, 219, 210,
249, 250, 250, 217, 180, 149, 123, 102, 120, 160,
153, 181, 190, 184, 188, 198, 198, 206, 203, 187,
204, 197, 184, 177, 252, 251, 251, 250, 229, 187,
156, 132, 108, 113, 144, 172, 177, 201, 207, 196,
212, 215, 208, 214, 205, 183, 215, 207, 237, 252,
253, 253, 228, 189, 157, 130, 108, 117, 143, 171,
185, 181, 184, 178, 177, 185, 165, 155, 156, 145,
138, 150, 197, 253, 253, 253, 253, 237, 198, 164,
136, 134, 144, 172, 177, 172, 160, 175, 150, 147,
139, 147, 137, 132, 132, 134, 129, 158, 254, 253,
252, 214, 177, 147, 122, 101, 90, 94, 105, 102,
108, 100, 111, 109, 117, 114, 110, 104, 100, 105,
101, 173, 243, 253, 254, 231, 192, 159, 132, 109,
91, 76, 67, 75, 73, 77, 69, 74, 70, 76,
67, 71, 63, 80, 67, 79, 191, 253, 251, 251,
210, 177, 147, 122, 101, 84, 75, 70, 77, 68,
81, 78, 86, 89, 89, 75, 85, 79, 84, 74,
86, 92, 130, 113, 106, 96, 130, 145, 171, 187,
210, 234, 219, 219, 223, 214, 218, 243, 240, 231,
236, 226, 225, 230, 223, 205, 198, 216, 220, 220,
233, 205, 222, 222, 199, 218, 205, 195, 196, 209,
199, 201, 193, 203, 193, 171, 182, 186, 174, 188,
173, 178, 188, 187, 183, 198, 191, 163, 193, 187,
175, 196, 204, 195, 207, 208, 204, 214, 209, 185,
198, 205, 202, 218, 207, 202, 200, 206, 192, 205,
198, 194, 172, 173, 180, 180, 186, 189, 190, 192,
180, 157, 157, 145, 147, 153, 170, 167, 183, 156,
160, 142, 191, 188, 162, 142, 131, 143, 129, 148,
162, 134, 172, 150, 194, 218, 201, 229, 202, 226,
204, 217, 205, 182, 173, 153, 186, 208, 192, 220,
192, 212, 208, 206, 215, 193, 193, 180, 191, 200,
199, 211, 205, 220, 227, 213, 231, 205, 215, 206,
201, 212, 212, 234, 235, 240, 239, 204, 233, 198,
214, 212, 206, 231, 224, 241, 241, 219, 237, 201,
230, 210, 227, 215, 209, 218, 226, 236, 238, 223,
241, 209, 232, 208, 229, 230, 216, 234, 228, 244,
245, 211, 229, 196, 218, 211, 225, 224, 186, 153,
127, 106, 90, 75, 62, 53, 47, 41, 46, 53,
56, 49, 48, 46, 47, 41, 48, 42, 42, 42,
44, 43, 38, 47, 45, 43, 37, 40, 36, 34,
35, 34, 35, 43, 38, 37, 34, 40, 35, 34,
34, 33, 32, 31, 31, 32, 36, 38, 39, 36,
36, 39, 39, 34, 34, 31, 34, 39, 36, 39,
36, 34, 33, 32, 29, 32, 31, 31, 28, 32,
34, 42, 37, 34, 30, 29, 30, 29, 25, 28,
23, 35, 32, 37, 34, 32, 35, 31, 28, 29,
30, 26, 28, 25, 46, 53, 58, 61, 55, 55,
58, 61, 52, 56, 53, 52, 48, 54, 54, 46,
52, 45, 47, 42, 42, 38, 39, 41, 45, 41,
44, 42, 39, 42, 35, 40, 34, 36, 35, 33,
40, 38, 36, 38, 34, 37, 32, 35, 31, 33,
32, 32, 32, 34, 33, 30, 39, 34, 34, 30,
33, 32, 29, 30, 33, 33, 42, 36, 36, 32,
33, 29, 31, 31, 30, 29, 29, 39, 38, 35,
41, 35, 30, 28, 29, 28, 26, 25, 25, 33,
32, 38, 33, 35, 33, 31, 29, 29, 29, 26,
26, 33, 38, 45, 53, 46, 46, 44, 44, 49,
51, 48, 50, 51, 54, 47, 48, 46, 47, 40,
43, 42, 44, 44, 42, 44, 50, 55, 50, 54,
45, 49, 41, 44, 39, 44, 45, 44, 49, 49,
50, 49, 51, 47, 46, 49, 43, 44, 45, 48,
46, 49, 47, 48, 46, 42, 42, 41, 45, 44,
42, 40, 43, 49, 49, 46, 43, 41, 39, 41,
37, 42, 40, 40, 39, 41, 48, 45, 46, 42,
43, 40, 36, 35, 38, 40, 38, 42, 45, 45,
42, 39, 39, 37, 40, 37, 36, 35, 37, 39,
45, 72, 60, 64, 55, 54, 52, 58, 52, 53,
51, 46, 50, 43, 49, 42, 51, 44, 42, 38,
39, 35, 39, 37, 43, 38, 35, 33, 40, 36,
32, 37, 34, 33, 33, 32, 33, 37, 33, 34,
32, 35, 31, 31, 30, 30, 28, 29, 29, 30,
27, 28, 32, 29, 28, 26, 29, 28, 28, 27,
31, 30, 37, 34, 30, 29, 27, 26, 29, 29,
26, 27, 27, 30, 29, 32, 27, 27, 28, 25,
27, 24, 23, 21, 23, 27, 32, 28, 29, 25,
29, 26, 25, 24, 24, 23, 23, 26, 39, 38,
34, 33, 36, 33, 32, 28, 36, 33, 33, 31,
37, 36, 37, 35, 33, 33, 34, 32, 30, 32,
30, 31, 35, 30, 32, 30, 32, 32, 27, 28,
26, 24, 24, 28, 28, 33, 30, 27, 28, 27,
27, 27, 27, 25, 25, 25, 27, 29, 34, 30,
35, 30, 32, 29, 30, 28, 27, 27, 31, 28,
31, 28, 28, 26, 24, 28, 25, 26, 25, 24,
24, 28, 31, 28, 28, 27, 25, 26, 24, 23,
23, 20, 27, 29, 30, 29, 29, 27, 30, 27,
26, 27, 24, 23, 22, 30, 44, 48, 52, 47,
46, 46, 46, 43, 39, 42, 38, 39, 42, 40,
33, 38, 33, 33, 29, 31, 27, 27, 29, 32,
32, 31, 35, 30, 34, 31, 31, 29, 28, 30,
28, 31, 32, 29, 29, 27, 29, 26, 29, 25,
28, 26, 25, 25, 28, 29, 31, 29, 28, 30,
28, 28, 27, 26, 24, 25, 26, 28, 30, 28,
27, 25, 23, 23, 22, 24, 22, 20, 27, 31,
30, 33, 28, 26, 23, 24, 21, 25, 23, 21,
25, 29, 29, 27, 29, 27, 26, 25, 24, 24,
21, 22, 23, 31, 37, 32, 34, 30, 27, 30,
27, 33, 29, 29, 28, 29, 32, 31, 33, 31,
31, 29, 27, 28, 29, 29, 31, 28, 31, 30,
33, 30, 30, 26, 28, 26, 30, 27, 29, 28,
26, 26, 23, 23, 27, 25, 23, 25, 22, 24,
22, 22, 23, 24, 26, 25, 24, 27, 26, 22,
25, 23, 22, 22, 26, 24, 24, 25, 24, 24,
21, 21, 24, 24, 21, 21, 24, 26, 26, 27,
25, 24, 24, 22, 22, 21, 21, 23, 26, 25,
28, 24, 23, 22, 21, 21, 22, 21, 22, 26,
26, 28, 28, 28, 34, 31, 31, 33, 33, 33,
29, 30, 27, 28, 31, 32, 33, 32, 29, 31,
28, 28, 27, 25, 25, 24, 28, 27, 25, 25,
25, 27, 25, 28, 30, 25, 25, 28, 27, 32,
28, 26, 27, 25, 27, 24, 24, 26, 27, 27,
25, 25, 26, 26, 26, 25, 28, 26, 25, 27,
24, 26, 27, 29, 26, 26, 27, 25, 27, 28,
25, 24, 27, 26, 26, 28, 26, 27, 27, 27,
26, 25, 25, 25, 23, 23, 28, 28, 29, 29,
24, 27, 28, 29, 25, 25, 27, 27, 24, 26,
34, 32, 29, 29, 26, 28, 29, 28, 25, 28,
29, 29, 27, 28, 28, 30, 26, 27, 26, 25,
27, 25, 27, 26, 30, 27, 27, 28, 27, 28,
24, 27, 26, 27, 25, 25, 28, 28, 29, 25,
26, 25, 25, 24, 24, 26, 24, 25, 25, 26,
27, 27, 25, 24, 25, 26, 24, 22, 23, 22,
25, 24, 24, 23, 22, 21, 21, 21, 19, 20,
20, 21, 21, 20, 22, 21, 20, 19, 19, 17,
18, 19, 18, 18, 17, 17, 19, 18, 16, 17,
16, 16, 17, 17, 16, 17, 17, 16, 17, 16,
16, 16, 16, 16, 17, 15, 16, 15, 14, 15,
15, 15, 15, 15, 14, 15, 14, 14, 15, 14,
15, 15, 15, 14, 14, 14, 16, 15, 13, 14,
14, 15, 14, 14, 14, 14, 14, 14, 15, 14,
14, 14, 13, 14, 14, 13, 15, 16, 15, 14,
14, 15, 14, 15, 14, 15, 15, 14, 15, 14,
14, 14, 14, 15, 14, 14, 14, 14, 14, 14,
14, 15, 14, 14, 14, 14, 14, 14, 14, 14,
13, 14, 14, 14, 14, 14, 15, 13, 14, 14,
14, 13, 15, 14, 15, 14, 14, 14, 14, 14,
14, 14, 14, 14, 15, 13, 15, 14, 15, 13,
14, 15, 14, 14, 15, 14, 15, 14, 14, 13,
15, 14, 14, 15, 15, 14, 14, 15, 13, 14,
13, 15, 13, 15, 14, 14, 13, 14, 15, 13,
14, 14, 14, 14, 13, 14, 14, 14, 14, 13,
15, 14, 14, 14, 15, 14, 15, 14, 14, 14,
14, 15, 14, 14, 14, 15, 13, 14, 14, 15,
15, 14, 15, 13, 14, 14, 15, 14, 15, 14,
15, 15, 15, 14, 15, 14, 15, 14, 14, 14,
15, 14, 14, 14, 14, 0
};


// Function wrappers to avoid putting the array
// at the top of the sketch.
uint8_t getMusic(uint32_t i) {
  return pgm_read_byte_near(music + i);
}

uint32_t getMusicSize() {
  return sizeof(music);
}

